summaryrefslogtreecommitdiff
path: root/test_requests.py
diff options
context:
space:
mode:
Diffstat (limited to 'test_requests.py')
-rwxr-xr-xtest_requests.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test_requests.py b/test_requests.py
index 6e49f027..d176ef45 100755
--- a/test_requests.py
+++ b/test_requests.py
@@ -310,8 +310,8 @@ class RequestsTestCase(unittest.TestCase):
requests.get("http://httpbin.org:1")
def test_LocationParseError(self):
- """Inputing a URL that cannot be parsed should raise a ConnectionError"""
- with pytest.raises(ConnectionError):
+ """Inputing a URL that cannot be parsed should raise an InvalidURL error"""
+ with pytest.raises(InvalidURL):
requests.get("http://fe80::5054:ff:fe5a:fc0")
def test_basicauth_with_netrc(self):